=================================
Leaderboard: redis backed leaderboard library
=================================

:Version: 1.1.2
:Download: http://pypi.python.org/pypi/leaderboard
:Source: https://github.com/agoragames/python-leaderboard
:Keywords: python, redis, leaderboard

.. contents::
    :local:

.. _pthon-leaderboard-overview:

Overview
========

Leaderboards backed by Redis in Python, http://redis.io.

Builds off ideas proposed in http://blog.agoragames.com/2011/01/01/creating-high-score-tables-leaderboards-using-redis/.

see https://github.com/agoragames/leaderboard/ for detailed usage information

.. _license:

License
=======

This software is licensed under the `New BSD License`. See the ``LICENSE``
file in the top distribution directory for the full license text.

.. # vim: syntax=rst expandtab tabstop=4 shiftwidth=4 shiftround

